summaryrefslogtreecommitdiff
path: root/src/gui/inventory.h
diff options
context:
space:
mode:
authorEugenio Favalli <elvenprogrammer@gmail.com>2004-09-30 16:51:29 +0000
committerEugenio Favalli <elvenprogrammer@gmail.com>2004-09-30 16:51:29 +0000
commit25246c487851b7d113d1fb1d3daf7dc1cdf000c5 (patch)
tree8047797b8daa160ba120bdeea9ad80d79e3a17bc /src/gui/inventory.h
parent9353cfbee08ae3e130e2e9dcfb0942ff465a8329 (diff)
downloadmana-client-25246c487851b7d113d1fb1d3daf7dc1cdf000c5.tar.gz
mana-client-25246c487851b7d113d1fb1d3daf7dc1cdf000c5.tar.bz2
mana-client-25246c487851b7d113d1fb1d3daf7dc1cdf000c5.tar.xz
mana-client-25246c487851b7d113d1fb1d3daf7dc1cdf000c5.zip
*** empty log message ***
Diffstat (limited to 'src/gui/inventory.h')
-rw-r--r--src/gui/inventory.h14
1 files changed, 3 insertions, 11 deletions
diff --git a/src/gui/inventory.h b/src/gui/inventory.h
index 61ec9e7b..21a958ab 100644
--- a/src/gui/inventory.h
+++ b/src/gui/inventory.h
@@ -53,26 +53,18 @@ class TmwInventory{
void create(int x, int y); // create the window
void draw(BITMAP *); // draw the window (if areDisplaying != 0 )
void show(bool val); // choose between showing and not showing the window
- void toggle() { if(areDisplaying){show(0);}else{show(1);} }
+ void toggle() {if(show_inventory){show(0);}else{show(1);}}
//API
int add_item(int index, int id, int quantity); // add a item
int remove_item(int id); // remove a item
- int changeNum(int idnum, int antal); // change number of a item
+ int change_quantity(int index, int quantity); // change number of a item
+ int increase_quantity(int index, int quantity); // increase quantity of a item
int useItem(int idnum);
//END API
private:
itemHolder items[INVENTORY_SIZE]; // this is the holder of items
DATAFILE *itemset;
bool show_inventory;
- int ghostX, ghostY, ghostID, ghostOldIDX,ghostOldIDY; //info needed when moving item
- int dragingItem, lastSelectedX,lastSelectedY; //info needed when moving item
- int areDisplaying, dragingWindow;
- int bigwindow;
- int xpos, ypos; // Where am I ?
- int itemMeny;
- int itemMeny_x, itemMeny_y;
- int itemIdn;
-
};
#endif